pub struct BackgroundSyncConfig {
pub onchain_wallet_sync_interval_secs: u64,
pub lightning_wallet_sync_interval_secs: u64,
pub fee_rate_cache_update_interval_secs: u64,
}Expand description
Options related to background syncing the Lightning and on-chain wallets.
Defaults
| Parameter | Value |
|---|---|
onchain_wallet_sync_interval_secs | 80 |
lightning_wallet_sync_interval_secs | 30 |
fee_rate_cache_update_interval_secs | 600 |
Fields
onchain_wallet_sync_interval_secs: u64The time in-between background sync attempts of the onchain wallet, in seconds.
Note: A minimum of 10 seconds is enforced when background syncing is enabled.
lightning_wallet_sync_interval_secs: u64The time in-between background sync attempts of the LDK wallet, in seconds.
Note: A minimum of 10 seconds is enforced when background syncing is enabled.
fee_rate_cache_update_interval_secs: u64The time in-between background update attempts to our fee rate cache, in seconds.
Note: A minimum of 10 seconds is enforced when background syncing is enabled.